@@ -116,7 +116,7 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.0.1
+1.0.3
 
 =head1 LICENSE
 
@@ -161,8 +161,8 @@ our @ISA = qw(Net::Simplify::Domain);
 sub list {
     my ($class, $criteria, $auth) = @_;
    
-    $auth = Net::SimplifyApi->get_authentication($auth);
-    my $result = Net::SimplifyApi->send_api_request("deposit", 'list', $criteria, $auth);
+    $auth = Net::Simplify::SimplifyApi->get_authentication($auth);
+    my $result = Net::Simplify::SimplifyApi->send_api_request("deposit", 'list', $criteria, $auth);
 
     Net::Simplify::DomainList->new($result, $class, $auth);
 }
@@ -170,8 +170,8 @@ sub list {
 sub find {
     my ($class, $id, $auth) = @_;
 
-    $auth = Net::SimplifyApi->get_authentication($auth);
-    my $result = Net::SimplifyApi->send_api_request("deposit", 'find', { id => $id }, $auth);
+    $auth = Net::Simplify::SimplifyApi->get_authentication($auth);
+    my $result = Net::Simplify::SimplifyApi->send_api_request("deposit", 'find', { id => $id }, $auth);
 
     $class->SUPER::new($result, $auth);
 }
