@@ -203,7 +203,7 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.0.1
+1.0.3
 
 =head1 LICENSE
 
@@ -249,8 +249,8 @@ sub create {
 
     my ($class, $params, $auth) = @_;
     
-    $auth = Net::SimplifyApi->get_authentication($auth);
-    my $result = Net::SimplifyApi->send_api_request("invoiceItem", 'create', $params, $auth);
+    $auth = Net::Simplify::SimplifyApi->get_authentication($auth);
+    my $result = Net::Simplify::SimplifyApi->send_api_request("invoiceItem", 'create', $params, $auth);
 
     $class->SUPER::new($result, $auth);
 }
@@ -259,17 +259,17 @@ sub delete {
 
     my ($self) = @_;
 
-    my $auth = Net::SimplifyApi->get_authentication($self->{_authentication});
+    my $auth = Net::Simplify::SimplifyApi->get_authentication($self->{_authentication});
 
     my $id = $self->{id};
-    $self->merge(Net::SimplifyApi->send_api_request("invoiceItem", 'delete', {id => $id}, $auth));
+    $self->merge(Net::Simplify::SimplifyApi->send_api_request("invoiceItem", 'delete', {id => $id}, $auth));
 }
 
 sub list {
     my ($class, $criteria, $auth) = @_;
    
-    $auth = Net::SimplifyApi->get_authentication($auth);
-    my $result = Net::SimplifyApi->send_api_request("invoiceItem", 'list', $criteria, $auth);
+    $auth = Net::Simplify::SimplifyApi->get_authentication($auth);
+    my $result = Net::Simplify::SimplifyApi->send_api_request("invoiceItem", 'list', $criteria, $auth);
 
     Net::Simplify::DomainList->new($result, $class, $auth);
 }
@@ -277,8 +277,8 @@ sub list {
 sub find {
     my ($class, $id, $auth) = @_;
 
-    $auth = Net::SimplifyApi->get_authentication($auth);
-    my $result = Net::SimplifyApi->send_api_request("invoiceItem", 'find', { id => $id }, $auth);
+    $auth = Net::Simplify::SimplifyApi->get_authentication($auth);
+    my $result = Net::Simplify::SimplifyApi->send_api_request("invoiceItem", 'find', { id => $id }, $auth);
 
     $class->SUPER::new($result, $auth);
 }
@@ -287,11 +287,11 @@ sub update {
 
     my ($self) = @_;
 
-    my $auth = Net::SimplifyApi->get_authentication($self->{_authentication});
+    my $auth = Net::Simplify::SimplifyApi->get_authentication($self->{_authentication});
     my $params = { %$self };
     delete $params->{_authentication};
 
-    $self->merge(Net::SimplifyApi->send_api_request("invoiceItem", 'update', $params, $auth));
+    $self->merge(Net::Simplify::SimplifyApi->send_api_request("invoiceItem", 'update', $params, $auth));
 }
 
 
