@@ -217,7 +217,7 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.0.1
+1.0.3
 
 =head1 LICENSE
 
@@ -263,8 +263,8 @@ sub create {
 
     my ($class, $params, $auth) = @_;
     
-    $auth = Net::SimplifyApi->get_authentication($auth);
-    my $result = Net::SimplifyApi->send_api_request("payment", 'create', $params, $auth);
+    $auth = Net::Simplify::SimplifyApi->get_authentication($auth);
+    my $result = Net::Simplify::SimplifyApi->send_api_request("payment", 'create', $params, $auth);
 
     $class->SUPER::new($result, $auth);
 }
@@ -272,8 +272,8 @@ sub create {
 sub list {
     my ($class, $criteria, $auth) = @_;
    
-    $auth = Net::SimplifyApi->get_authentication($auth);
-    my $result = Net::SimplifyApi->send_api_request("payment", 'list', $criteria, $auth);
+    $auth = Net::Simplify::SimplifyApi->get_authentication($auth);
+    my $result = Net::Simplify::SimplifyApi->send_api_request("payment", 'list', $criteria, $auth);
 
     Net::Simplify::DomainList->new($result, $class, $auth);
 }
@@ -281,8 +281,8 @@ sub list {
 sub find {
     my ($class, $id, $auth) = @_;
 
-    $auth = Net::SimplifyApi->get_authentication($auth);
-    my $result = Net::SimplifyApi->send_api_request("payment", 'find', { id => $id }, $auth);
+    $auth = Net::Simplify::SimplifyApi->get_authentication($auth);
+    my $result = Net::Simplify::SimplifyApi->send_api_request("payment", 'find', { id => $id }, $auth);
 
     $class->SUPER::new($result, $auth);
 }
